.. currentmodule:: signalyzer

.. _signal processing:

Signal Processing
=================

The :class:`Trace` class has *methods* for `signal processing`_  the
:attr:`~Trace.samples` of a :class:`Trace`.

Clipping
--------


Smoothing
---------



Filtering
---------



Moving Window Functions
-----------------------




.. toctree::
   :maxdepth: 3
   :caption: Signal Processing
   :hidden:

   clipping
   first-order-lag
   exponential-smoothing
   iir-filters
   window-generator
   moving-differentiation
   moving-average
   moving-linear-regression
